from collective.oembed.tests import base

class Test(base.UnitTestCase):
    
    def setUp(self):
        super(Test, self).setUp()
        from collective.oembed import viewlet
        self.viewlet = viewlet.Discovery(self.context, 
                                         self.request, None)
        self.viewlet.site_url = 'http://nohost'
    
    def test_oembed_url_json(self):
        url = self.viewlet.oembed_url_json()
        self.failUnless(url == u'http://nohost/@@oembed?url=http%3A%2F%2Fnohost.com%2Fmyid&format=json',url)

    def test_oembed_url_xml(self):
        url = self.viewlet.oembed_url_xml()
        self.failUnless(url == u'http://nohost/@@oembed?url=http%3A%2F%2Fnohost.com%2Fmyid&format=xml',url)

    def test_title(self):
        title = self.viewlet.title()
        self.failUnless(title.endswith('oEmbed Profile'))
    
    def test_query(self):
        query = self.viewlet.query()
        self.failUnless('url' in query)
        self.failUnless(query['url'] == self.context.absolute_url())

class TestIntegration(base.TestCase):

    def setUp(self):
        super(TestIntegration, self).setUp()
        from collective.oembed import viewlet
        self.viewlet = viewlet.Discovery(self.portal, 
                                         self.portal.REQUEST, None)
        self.viewlet.site_url = 'http://nohost'

    def test_rendering(self):
        import re
        text = self.viewlet.render()
        json_re = '<link rel="alternate" type="application/json\+oembed" href=".*" title=".*" />'
        xml_re = '<link rel="alternate" type="text/xml\+oembed" href=".*" title=".*" />'
        self.failUnless(re.search(json_re, text) is not None)
        self.failUnless(re.search(xml_re, text) is not None)

def test_suite():
    """This sets up a test suite that actually runs the tests in the class
    above
    """
    return base.build_test_suite((Test, TestIntegration))



import json
from urlparse import urlparse
from zope.component.hooks import getSite

from Products.CMFCore.utils import getToolByName
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.Five import BrowserView

class OEmbedProvider(BrowserView):
    """OEmbed Provider"""
    
    index_xml = ViewPageTemplateFile('provider_xml.pt')
    
    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.format = None
        self.url = None
        self.maxwidth = None
        self.maxheight = None
        self.embed = {}
        
        self._site = None
        self._target = None

    
    def __call__(self):
        try:
            self.update()
            return self.render()
        except KeyError, e:
            return e
        except ValueError, e:
            return e

    def update(self):
#        import pdb;pdb.set_trace()
        if self.format is None:
            self.format = self.request.get('format',None)

        if self.format is None or not self.format:
            self.format = 'json'
        if self.format == 'json':
            self.request.response.setHeader('Content-Type','application/json')

        if self.format not in ('json','xml'):
            raise ValueError('format parameter must be in json, xml')

        if self.url is None:
            self.url = self.request.get('url',None)
        if self.url is None:
            raise KeyError('you must provide url parameter')

        if self.maxwidth is None:
            self.maxwidth = self.request.get('maxwidth',None)
        if self.maxheight is None:
            self.maxheight = self.request.get('maxheight',None)

        path = self.get_path()
        site = self.get_site()
        if site is None or path is None:
            return

        ob = self.get_target()
        if ob is None:
            return

        self.build_info(ob, site)

    def build_info(self, context, site):
        ob = context
        site_title = site.Title()

        title = ob.Title()
        if type(title) != unicode:
            title.decode('utf-8')
        if type(site_title) != unicode:
            site_title = site_title.decode('utf-8')


        e = self.embed
        e[u'version'] = '1.0'
        e[u'title'] = title
        e[u'author_name'] = ob.Creator()
        e[u'author_url'] = site.absolute_url()+'/author/' + ob.Creator()
        e[u'provider_name'] = site_title
        e[u'provider_url'] = site.absolute_url()
        if ob.portal_type == 'Image':
            e[u'type'] = 'photo'
            e[u'url'] = ob.absolute_url()
            image = ob.getField('image').get(ob)
            e[u'width'] = image.width
            e[u'height'] = image.height
        else:
            e[u'type'] = 'link'

    def render(self):
        res = self.embed
        if self.format == 'json':
            return json.dumps(res)

        return self.index_xml()

    def get_path(self):
        parsed = urlparse(self.url)
        path = parsed.path
        return path
    
    def get_site(self):
        if self._site is None:
            self._site = getSite()
        return self._site

    def get_target(self):
        site = self.get_site()
        path = self.get_path()
        portal_path = site.portal_url.getPortalPath()
        if path.startswith(portal_path):
            path = path[len(portal_path):]

        if site is None:
            return

        if self._target is None:
            try:
                self._target = site.restrictedTraverse(path[1:])#remove heading /
            except KeyError,e:
                logger.error(e)
                return

        return self._target



from collective.oembed.tests import base
from collective.oembed.tests import utils

class Test(base.UnitTestCase):
    
    def setUp(self):
        super(Test, self).setUp()
        from collective.oembed import provider
        self.provider = provider.OEmbedProvider(self.context, self.request)

    def test_attributes(self):
        self.failUnless(hasattr(self.provider,'url'))
        self.failUnless(hasattr(self.provider,'maxwidth'))
        self.failUnless(hasattr(self.provider,'maxheight'))
        self.failUnless(hasattr(self.provider,'format'))

        self.failUnless(self.provider.url is None)
        self.failUnless(self.provider.maxwidth is None)
        self.failUnless(self.provider.maxheight is None)
        self.failUnless(self.provider.format is None)

    def test_update(self):
        self.request['url'] = 'http://nohost/test-folder'
        format_a = self.provider.format
        self.failUnless(format_a is None)

        self.provider.update()
        format_b = self.provider.format
        self.failUnless(format_b == 'json')

        self.provider.format = None
        self.request['format']="xml"
        self.provider.update()
        format_c = self.provider.format
        self.failUnless(format_c == 'xml')

        self.provider.format = None
        self.request['format']="wrong"
        self.assertRaises(ValueError, self.provider.update)


    def test_get_path(self):
        self.provider.url = 'http://nohost/test-folder'
        path = self.provider.get_path()
        self.failUnless(path == '/test-folder')

        self.provider.url = 'http://www.youtube.com/playlist?list=PL84E044CCF097C8CB'
        path = self.provider.get_path()
        self.failUnless(path == '/playlist')

    def test_build_info(self):
        context = self.context
        site = utils.FakeContext()
        site.title = "My Plone site"
        site.id="Plone"
        self.provider.build_info(context, site)
        data = self.provider.embed
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"link")

class TestIntegration(base.TestCase):
    
    def setUp(self):
        super(TestIntegration, self).setUp()
        self.view = self.portal.restrictedTraverse('@@oembed')
        self.portal.REQUEST['url']=self.folder.absolute_url()
    
    def test_call(self):
        render = self.view()
        self.failUnless(render is not None)
        import json
        data = json.loads(render)
        self.failUnless(u'type' in data)
        self.failUnless(data[u'type'] == u'link')
        self.failUnless(data[u'title'] == u'Test folder')
    
    def test_call_xml(self):
        self.portal.REQUEST['format']='xml'
        render = self.view()
        self.failUnless(render is not None)

def test_suite():
    """This sets up a test suite that actually runs the tests in the class
    above
    """
    return base.build_test_suite((Test, TestIntegration))



from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
from collective.oembed.i18n import messageFactory as _

embedMethods = SimpleVocabulary(
    [SimpleTerm(value=u'append',  title=_(u'append')),
     SimpleTerm(value=u'fill',    title=_(u'fill')),
     SimpleTerm(value=u'replace', title=_(u'replace')),
     SimpleTerm(value=u'auto', title=_(u'auto'))]
    )




import re
import urllib
import urllib2
import json
import logging

from zope import component
from zope import interface
from plone.memoize.ram import cache

import oembed
from plone.registry.interfaces import IRegistry

from collective.oembed import interfaces
from collective.oembed import endpoints
from Products.Five.browser import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

try:
    from collective.embedly.interfaces import IEmbedlySettings
    HAS_COLLECTIVE_EMBEDLY = True
except ImportError,e:
    HAS_COLLECTIVE_EMBEDLY = False

logger = logging.getLogger('collective.oembed')

def _render_details_cachekey(method, self, url, maxwidth=None, maxheight=None,
                             format='json'):
    return '%s-%s-%s-%s'%(url, maxwidth, maxheight, format)

TEMPLATES = {u"link":u"""
    <div class="oembed-wrapper oembed-link">
      <a href="%(url)s" target="_blank">%(title)s"></a>
      <div>%(html)s</div>
    </div> 
    """,
                 u"photo":u"""
    <div class="oembed-wrapper oembed-photo">
      <p><a href="%(url)s" target="_blank">%(title)s">
        <img src="%(url)s" alt="%(title)s"/>
      </a></p>
      <div>%(html)s</div>
    </div> 
    """,
                 u"rich":u"""
    <div class="oembed-wrapper oembed-rich">
      %(html)s
    </div> 
    """,
                 u"video":u"""
    <div class="oembed-wrapper oembed-video">
      %(html)s
    </div> 
    """}

class Consumer(object):
    """Consumer utility"""
    interface.implements(interfaces.IConsumer)

    def __init__(self):
        self.consumer = None
        self.embedly_apikey = None

    @cache(_render_details_cachekey)
    def get_data(self, url, maxwidth=None, maxheight=None, format='json'):
        return self.get_data_uncached(url, maxwidth, maxheight, format)

    def get_data_uncached(self, url, maxwidth=None, maxheight=None,
                          format='json'):
        self.initialize_consumer()
        request = {}
        if maxwidth is not None:
            request['maxwidth'] = maxwidth
        if maxheight is not None:
            request['maxheight'] = maxheight
        request['format'] = format

        try:
            response = self.consumer.embed(url,**request)
            return response.getData()
        except oembed.OEmbedNoEndpoint, e:
            logger.info(e)

    def initialize_consumer(self):
        if self.consumer is None:

            consumer = oembed.OEmbedConsumer()
            _enpoints = endpoints.load_all_endpoints(embedly_apikey=self.embedly_apikey)
            for endpoint in _enpoints:
                consumer.addEndpoint(endpoint)
    
            self.consumer = consumer

    def embed(self, url, maxwidth=None, maxheight=None, format='json'):
        data = self.get_data(url, maxwidth=maxwidth, maxheight=maxheight,
                             format=format)
        if data is None or u"type" not in data:
            return u""
        return TEMPLATES[data[u"type"]]%data

class ConsumerView(BrowserView):
    """base browserview to display embed stuff"""

    embed_templates = {u'photo': ViewPageTemplateFile('oembed_photo.pt'),
                 u'video': ViewPageTemplateFile('oembed_video.pt'),
                 u'link':  ViewPageTemplateFile('oembed_link.pt'),
                 u'rich':  ViewPageTemplateFile('oembed_rich.pt')}

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.data = None
        self._utility = None
        self._url = None
        self._format = "json"
        self._maxwidth = None
        self._maxheight = None
        self.embeded = u""



    def update(self):
        """initialize all data"""
        if self._utility is None:
            self._utility = component.getUtility(interfaces.IConsumer)
            self._utility.embedly_apikey = self.embedly_apikey()

        if self._url is None:
            self._url = self.context.getRemoteUrl()

    def update_data(self):
        """load data extracted from the context"""
        self.update()
        if self.data is None:
            self.data = self._utility.get_data(self._url,
                                               maxwidth=self._maxwidth,
                                               maxheight=self._maxheight,
                                               format=self._format)

    def get_data(self, url, maxwidth=None, maxheight=None, format='json'):
        self.update()
        data = self._utility.get_data(url,
                                      maxwidth=maxwidth,
                                      maxheight=maxheight,
                                      format=format)
        return data

    def embed(self, url, maxwidth=None, maxheight=None, format='json'):

        data = self.get_data(url, maxwidth, maxheight, format)
        return self.display_data(data)

    def embed_auto(self):
        """This method extract params from the context"""
        self.update()
        self.update_data()
        return self.display_data(self.data)

    def display_data(self, data):
        if data is None:
            return u""

        if u'type' not in data:
            logger.info('no type in data for %s'%url)

        template = self.embed_templates.get(data[u'type'])

        return template(self)

    def embedly_apikey(self):
        """Return the api key from collective.embedly if found or from
        our own settings"""
        proxy = None
        registry = component.queryUtility(IRegistry)

        if registry is None:
            return

        if HAS_COLLECTIVE_EMBEDLY:
            try:
                proxy = registry.forInterface(IEmbedlySettings)
                return proxy.api_key
            except KeyError, e:
                pass

        try:
            proxy = registry.forInterface(interfaces.IOEmbedSettings)
            return proxy.embedly_apikey
        except KeyError, e:
            pass



import unittest2 as unittest
from zope import interface
from plone.app import testing
from collective.oembed.tests import layer
from collective.oembed.tests import utils



class UnitTestCase(unittest.TestCase):
    
    def setUp(self):
        from zope.annotation.interfaces import IAttributeAnnotatable
        from collective.oembed.interfaces import OEmbedLayer
        super(UnitTestCase, self).setUp()
        self.context = utils.FakeContext()
        self.request = utils.Request()
        interface.alsoProvides(self.request,
                               (IAttributeAnnotatable,OEmbedLayer))

class TestCase(unittest.TestCase):

    layer = layer.INTEGRATION

    def setUp(self):
        from zope.annotation.interfaces import IAttributeAnnotatable
        from collective.oembed.interfaces import OEmbedLayer
        interface.alsoProvides(self.layer['request'],
                               (IAttributeAnnotatable,OEmbedLayer))
        super(TestCase, self).setUp()
        self.portal = self.layer['portal']
        testing.setRoles(self.portal, testing.TEST_USER_ID, ['Manager'])
        self.portal.invokeFactory('Folder', 'test-folder')
        testing.setRoles(self.portal, testing.TEST_USER_ID, ['Member'])
        self.folder = self.portal['test-folder']
        self.folder.setTitle('Test folder')


class FunctionalTestCase(unittest.TestCase):

    layer = layer.FUNCTIONAL

    def setUp(self):
        from zope.annotation.interfaces import IAttributeAnnotatable
        from collective.oembed.interfaces import OEmbedLayer
        interface.alsoProvides(self.layer['request'],
                               (IAttributeAnnotatable,OEmbedLayer))
        self.portal = self.layer['portal']
        testing.setRoles(self.portal, testing.TEST_USER_ID, ['Manager'])
        self.portal.invokeFactory('Folder', 'test-folder')
        testing.setRoles(self.portal, testing.TEST_USER_ID, ['Member'])
        self.folder = self.portal['test-folder']
        self.folder.setTitle('Test folder')

def build_test_suite(test_classes):
    suite = unittest.TestSuite()
    for klass in test_classes:
        suite.addTest(unittest.makeSuite(klass))
    return suite



from collective.oembed.tests import base
from collective.oembed.tests import utils

class Test(base.UnitTestCase):
    
    def setUp(self):
        super(Test, self).setUp()
        from collective.oembed import endpoints
        self.module = endpoints
        self.regex_providers = endpoints.REGEX_PROVIDERS
    
    def test_load_all_endpoints(self):
        from collective.oembed import endpoints
        all_endpoints = endpoints.load_all_endpoints()
        len_endpoints = len(all_endpoints)
        self.failUnless(len_endpoints>0)
        
        all_endpoints = endpoints.load_all_endpoints(embedly_apikey="fakeapikey")
        self.failUnless(len(all_endpoints)==len_endpoints + 1)

    def test_WordpressEndPoint(self):
        from collective.oembed import endpoints
        wordpress = endpoints.WordpressEndPoint()
        url = 'http://public-api.wordpress.com/oembed/1.0/'
        self.failUnless(wordpress._urlApi==url)
        request_url = 'http://toutpt.wordpress.com/2011/02/10/collective-portlet-itemview/'
        request = wordpress.request(request_url)
        self.failUnless(request.startswith(url))

    def test_EmbedlyEndPoint(self):
        from collective.oembed import endpoints
        embedly = endpoints.EmbedlyEndPoint('fakeapikey')
        url = 'http://api.embed.ly/1/oembed'
        self.failUnless(embedly._urlApi==url)
        request_url = 'http://dontcare.com/toto'
        request = embedly.request(request_url)
        self.failUnless(request.startswith(url))
        self.failUnless('key=fakeapikey' in request)


def test_suite():
    """This sets up a test suite that actually runs the tests in the class
    above
    """
    return base.build_test_suite((Test,))



from plone.testing import z2

from plone.app.testing import PloneSandboxLayer
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import IntegrationTesting, FunctionalTesting

class CollectiveLayer(PloneSandboxLayer):
    default_bases = (PLONE_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load ZCML
        import collective.oembed
        self.loadZCML(package=collective.oembed)

        # Install product and call its initialize() function
        z2.installProduct(app, 'collective.oembed')

    def setUpPloneSite(self, portal):
        # Install into Plone site using portal_setup
        self.applyProfile(portal, 'collective.oembed:default')

    def tearDownZope(self, app):
        # Uninstall product
        z2.uninstallProduct(app, 'collective.oembed')

FIXTURE = CollectiveLayer()

INTEGRATION = IntegrationTesting(bases=(FIXTURE,), name="OEmbed:Integration")
FUNCTIONAL = FunctionalTesting(bases=(FIXTURE,), name="OEmbed:Functional")



import oembed

REGEX_PROVIDERS = [
 {u'regex': ['regex:.*youtube\.com/watch.*','regex:.*youtube\.com/playlist.*'],
  u'endpoint':'http://www.youtube.com/oembed'},
 {u'regex':['http://*.flickr.com/*'],
  u'endpoint':'http://www.flickr.com/services/oembed'},
 {u'regex':['http://*.viddler.com/*'],
  u'endpoint':'http://lab.viddler.com/services/oembed/'},
 {u'regex':['http://qik.com/video/*','http://qik.com/*'],
  u'endpoint':'http://qik.com/api/oembed.{format}'},
 {u'regex':['http://*revision3.com/*'],
  u'endpoint':'http://revision3.com/api/oembed/'},
 {u'regex':['http://www.hulu.com/watch/*'],
  u'endpoint':'http://www.hulu.com/api/oembed.{format}'},
 {u'regex':['http://vimeo.com/*'],
  u'endpoint':'http://vimeo.com/api/oembed.{format}'},
 {u'regex':['http://www.collegehumor.com/video/*'],
  u'endpoint':'http://www.collegehumor.com/oembed.{format}'},
 {u'regex':['http://www.polleverywhere.com/polls/*','http://www.polleverywhere.com/multiple_choice_polls/*','http://www.polleverywhere.com/free_text_polls/*'],
  u'endpoint':'http://www.polleverywhere.com/services/oembed/'},
 {u'regex':['http://www.ifixit.com/*'],
  u'endpoint':'http://www.ifixit.com/Embed'},
 {u'regex':['http://*.smugmug.com/*'],
  u'endpoint':'http://api.smugmug.com/services/oembed/'},
 {u'regex':['http://www.slideshare.net/*/*'],
  u'endpoint':'http://www.slideshare.net/api/oembed/2'},
 {u'regex':['http://www.23hq.com/*/photo/*'],
  u'endpoint':'http://www.23hq.com/23/oembed'},
 {u'regex':['http://www.5min.com/video/*'],
  u'endpoint':'http://api.5min.com/oembed.{format}'}, #http://www.5min.com/APIDocs/Embed.aspx
 {u'regex':['https://twitter.com/*/status*/*'],
  u'endpoint':'https://api.twitter.com/1/statuses/oembed.{format}'}, #https://dev.twitter.com/docs/embedded-tweets
 {u'regex':['regex:.*photobucket\\.com/(albums|groups)/.+$'],
  u'endpoint':'http://photobucket.com/oembed'}, #http://pic.pbsrc.com/dev_help/Metadata/Metadata_Discovery.htm
 {u'regex':['http://*.kinomap.com/*'],
  u'endpoint':'http://www.kinomap.com/oembed'}, #http://pic.pbsrc.com/dev_help/Metadata/Metadata_Discovery.htm
 {u'regex':['http://*yfrog.com/*'],
  u'endpoint':'http://www.yfrog.com/api/oembed'}, #http://yfrog.com/page/api#a8
 {u'regex':['http://www.dailymotion.com/video/*'],
  u'endpoint':'http://www.dailymotion.com/services/oembed'}, #http://www.dailymotion.com/doc/api/oembed.html
 {u'regex':['http://*.clikthrough.com/theater/video/*'],
  u'endpoint':'http://clikthrough.com/services/oembed'}, #
 {u'regex':['http://dotsub.com/view/*'],
  u'endpoint':'http://dotsub.com/services/oembed'}, #http://solutions.dotsub.com/oEmbed
]

class EmbedlyEndPoint(oembed.OEmbedEndpoint):
    """override this one to add api key"""

    def __init__(self, apikey):
        url = 'http://api.embed.ly/1/oembed'
        embedly_re = 'regex:((http://(.*yfrog\..*/.*|twitter\.com/.*/status/.*/photo/.*|twitter\.com/.*/statuses/.*/photo|pic\.twitter\.com/.*|www\.twitter\.com/.*/statuses/.*/photo/.*|mobile\.twitter\.com/.*/status/.*/photo/.*|mobile\.twitter\.com/.*/statuses/.*/photo/.*|www\.flickr\.com/photos/.*|flic\.kr/.*|twitpic\.com/.*|www\.twitpic\.com/.*|twitpic\.com/photos/.*|www\.twitpic\.com/photos/.*|.*imgur\.com/.*|.*\.posterous\.com/.*|post\.ly/.*|twitgoo\.com/.*|i.*\.photobucket\.com/albums/.*|s.*\.photobucket\.com/albums/.*|media\.photobucket\.com/image/.*|phodroid\.com/.*/.*/.*|www\.mobypicture\.com/user/.*/view/.*|moby\.to/.*|xkcd\.com/.*|www\.xkcd\.com/.*|imgs\.xkcd\.com/.*|www\.asofterworld\.com/index\.php\?id=.*|www\.asofterworld\.com/.*\.jpg|asofterworld\.com/.*\.jpg|www\.qwantz\.com/index\.php\?comic=.*|23hq\.com/.*/photo/.*|www\.23hq\.com/.*/photo/.*|.*dribbble\.com/shots/.*|drbl\.in/.*|.*\.smugmug\.com/.*|.*\.smugmug\.com/.*#.*|emberapp\.com/.*/images/.*|emberapp\.com/.*/images/.*/sizes/.*|emberapp\.com/.*/collections/.*/.*|emberapp\.com/.*/categories/.*/.*/.*|embr\.it/.*|picasaweb\.google\.com.*/.*/.*#.*|picasaweb\.google\.com.*/lh/photo/.*|picasaweb\.google\.com.*/.*/.*|dailybooth\.com/.*/.*|brizzly\.com/pic/.*|pics\.brizzly\.com/.*\.jpg|img\.ly/.*|www\.tinypic\.com/view\.php.*|tinypic\.com/view\.php.*|www\.tinypic\.com/player\.php.*|tinypic\.com/player\.php.*|www\.tinypic\.com/r/.*/.*|tinypic\.com/r/.*/.*|.*\.tinypic\.com/.*\.jpg|.*\.tinypic\.com/.*\.png|meadd\.com/.*/.*|meadd\.com/.*|.*\.deviantart\.com/art/.*|.*\.deviantart\.com/gallery/.*|.*\.deviantart\.com/#/.*|fav\.me/.*|.*\.deviantart\.com|.*\.deviantart\.com/gallery|.*\.deviantart\.com/.*/.*\.jpg|.*\.deviantart\.com/.*/.*\.gif|.*\.deviantart\.net/.*/.*\.jpg|.*\.deviantart\.net/.*/.*\.gif|www\.fotopedia\.com/.*/.*|fotopedia\.com/.*/.*|photozou\.jp/photo/show/.*/.*|photozou\.jp/photo/photo_only/.*/.*|instagr\.am/p/.*|instagram\.com/p/.*|skitch\.com/.*/.*/.*|img\.skitch\.com/.*|share\.ovi\.com/media/.*/.*|www\.questionablecontent\.net/|questionablecontent\.net/|www\.questionablecontent\.net/view\.php.*|questionablecontent\.net/view\.php.*|questionablecontent\.net/comics/.*\.png|www\.questionablecontent\.net/comics/.*\.png|picplz\.com/.*|twitrpix\.com/.*|.*\.twitrpix\.com/.*|www\.someecards\.com/.*/.*|someecards\.com/.*/.*|some\.ly/.*|www\.some\.ly/.*|pikchur\.com/.*|achewood\.com/.*|www\.achewood\.com/.*|achewood\.com/index\.php.*|www\.achewood\.com/index\.php.*|www\.whosay\.com/content/.*|www\.whosay\.com/photos/.*|www\.whosay\.com/videos/.*|say\.ly/.*|ow\.ly/i/.*|color\.com/s/.*|bnter\.com/convo/.*|mlkshk\.com/p/.*|lockerz\.com/s/.*|lightbox\.com/.*|www\.lightbox\.com/.*|soundcloud\.com/.*|soundcloud\.com/.*/.*|soundcloud\.com/.*/sets/.*|soundcloud\.com/groups/.*|snd\.sc/.*|www\.last\.fm/music/.*|www\.last\.fm/music/+videos/.*|www\.last\.fm/music/+images/.*|www\.last\.fm/music/.*/_/.*|www\.last\.fm/music/.*/.*|www\.mixcloud\.com/.*/.*/|www\.radionomy\.com/.*/radio/.*|radionomy\.com/.*/radio/.*|www\.hark\.com/clips/.*|www\.rdio\.com/#/artist/.*/album/.*|www\.rdio\.com/artist/.*/album/.*|www\.zero-inch\.com/.*|.*\.bandcamp\.com/|.*\.bandcamp\.com/track/.*|.*\.bandcamp\.com/album/.*|freemusicarchive\.org/music/.*|www\.freemusicarchive\.org/music/.*|freemusicarchive\.org/curator/.*|www\.freemusicarchive\.org/curator/.*|www\.npr\.org/.*/.*/.*/.*/.*|www\.npr\.org/.*/.*/.*/.*/.*/.*|www\.npr\.org/.*/.*/.*/.*/.*/.*/.*|www\.npr\.org/templates/story/story\.php.*|huffduffer\.com/.*/.*|www\.audioboo\.fm/boos/.*|audioboo\.fm/boos/.*|boo\.fm/b.*|www\.xiami\.com/song/.*|xiami\.com/song/.*|www\.saynow\.com/playMsg\.html.*|www\.saynow\.com/playMsg\.html.*|grooveshark\.com/.*|radioreddit\.com/songs.*|www\.radioreddit\.com/songs.*|radioreddit\.com/\?q=songs.*|www\.radioreddit\.com/\?q=songs.*|www\.gogoyoko\.com/song/.*|.*amazon\..*/gp/product/.*|.*amazon\..*/.*/dp/.*|.*amazon\..*/dp/.*|.*amazon\..*/o/ASIN/.*|.*amazon\..*/gp/offer-listing/.*|.*amazon\..*/.*/ASIN/.*|.*amazon\..*/gp/product/images/.*|.*amazon\..*/gp/aw/d/.*|www\.amzn\.com/.*|amzn\.com/.*|www\.shopstyle\.com/browse.*|www\.shopstyle\.com/action/apiVisitRetailer.*|api\.shopstyle\.com/action/apiVisitRetailer.*|www\.shopstyle\.com/action/viewLook.*|itunes\.apple\.com/.*|gist\.github\.com/.*|twitter\.com/.*/status/.*|twitter\.com/.*/statuses/.*|www\.twitter\.com/.*/status/.*|www\.twitter\.com/.*/statuses/.*|mobile\.twitter\.com/.*/status/.*|mobile\.twitter\.com/.*/statuses/.*|www\.crunchbase\.com/.*/.*|crunchbase\.com/.*/.*|www\.slideshare\.net/.*/.*|www\.slideshare\.net/mobile/.*/.*|slidesha\.re/.*|scribd\.com/doc/.*|www\.scribd\.com/doc/.*|scribd\.com/mobile/documents/.*|www\.scribd\.com/mobile/documents/.*|screenr\.com/.*|polldaddy\.com/community/poll/.*|polldaddy\.com/poll/.*|answers\.polldaddy\.com/poll/.*|www\.5min\.com/Video/.*|www\.howcast\.com/videos/.*|www\.screencast\.com/.*/media/.*|screencast\.com/.*/media/.*|www\.screencast\.com/t/.*|screencast\.com/t/.*|issuu\.com/.*/docs/.*|www\.kickstarter\.com/projects/.*/.*|www\.scrapblog\.com/viewer/viewer\.aspx.*|foursquare\.com/.*|www\.foursquare\.com/.*|4sq\.com/.*|ping\.fm/p/.*|chart\.ly/symbols/.*|chart\.ly/.*|maps\.google\.com/maps\?.*|maps\.google\.com/\?.*|maps\.google\.com/maps/ms\?.*|.*\.craigslist\.org/.*/.*|my\.opera\.com/.*/albums/show\.dml\?id=.*|my\.opera\.com/.*/albums/showpic\.dml\?album=.*&picture=.*|tumblr\.com/.*|.*\.tumblr\.com/post/.*|www\.polleverywhere\.com/polls/.*|www\.polleverywhere\.com/multiple_choice_polls/.*|www\.polleverywhere\.com/free_text_polls/.*|www\.quantcast\.com/wd:.*|www\.quantcast\.com/.*|siteanalytics\.compete\.com/.*|statsheet\.com/statplot/charts/.*/.*/.*/.*|statsheet\.com/statplot/charts/e/.*|statsheet\.com/.*/teams/.*/.*|statsheet\.com/tools/chartlets\?chart=.*|.*\.status\.net/notice/.*|identi\.ca/notice/.*|brainbird\.net/notice/.*|shitmydadsays\.com/notice/.*|www\.studivz\.net/Profile/.*|www\.studivz\.net/l/.*|www\.studivz\.net/Groups/Overview/.*|www\.studivz\.net/Gadgets/Info/.*|www\.studivz\.net/Gadgets/Install/.*|www\.studivz\.net/.*|www\.meinvz\.net/Profile/.*|www\.meinvz\.net/l/.*|www\.meinvz\.net/Groups/Overview/.*|www\.meinvz\.net/Gadgets/Info/.*|www\.meinvz\.net/Gadgets/Install/.*|www\.meinvz\.net/.*|www\.schuelervz\.net/Profile/.*|www\.schuelervz\.net/l/.*|www\.schuelervz\.net/Groups/Overview/.*|www\.schuelervz\.net/Gadgets/Info/.*|www\.schuelervz\.net/Gadgets/Install/.*|www\.schuelervz\.net/.*|myloc\.me/.*|pastebin\.com/.*|pastie\.org/.*|www\.pastie\.org/.*|redux\.com/stream/item/.*/.*|redux\.com/f/.*/.*|www\.redux\.com/stream/item/.*/.*|www\.redux\.com/f/.*/.*|cl\.ly/.*|cl\.ly/.*/content|speakerdeck\.com/u/.*/p/.*|www\.kiva\.org/lend/.*|www\.timetoast\.com/timelines/.*|storify\.com/.*/.*|.*meetup\.com/.*|meetu\.ps/.*|www\.dailymile\.com/people/.*/entries/.*|.*\.kinomap\.com/.*|www\.metacdn\.com/r/c/.*/.*|www\.metacdn\.com/r/m/.*/.*|prezi\.com/.*/.*|.*\.uservoice\.com/.*/suggestions/.*|formspring\.me/.*|www\.formspring\.me/.*|formspring\.me/.*/q/.*|www\.formspring\.me/.*/q/.*|twitlonger\.com/show/.*|www\.twitlonger\.com/show/.*|tl\.gd/.*|www\.qwiki\.com/q/.*|crocodoc\.com/.*|.*\.crocodoc\.com/.*|www\.wikipedia\.org/wiki/.*|www\.wikimedia\.org/wiki/File.*|graphicly\.com/.*/.*/.*|.*youtube\.com/watch.*|.*\.youtube\.com/v/.*|youtu\.be/.*|.*\.youtube\.com/user/.*|.*\.youtube\.com/.*#.*/.*|m\.youtube\.com/watch.*|m\.youtube\.com/index.*|.*\.youtube\.com/profile.*|.*\.youtube\.com/view_play_list.*|.*\.youtube\.com/playlist.*|.*twitch\.tv/.*|.*justin\.tv/.*/b/.*|.*justin\.tv/.*/w/.*|.*twitch\.tv/.*|.*twitch\.tv/.*/b/.*|www\.ustream\.tv/recorded/.*|www\.ustream\.tv/channel/.*|www\.ustream\.tv/.*|qik\.com/video/.*|qik\.com/.*|qik\.ly/.*|.*revision3\.com/.*|.*\.dailymotion\.com/video/.*|.*\.dailymotion\.com/.*/video/.*|collegehumor\.com/video:.*|collegehumor\.com/video/.*|www\.collegehumor\.com/video:.*|www\.collegehumor\.com/video/.*|.*twitvid\.com/.*|www\.break\.com/.*/.*|vids\.myspace\.com/index\.cfm\?fuseaction=vids\.individual&videoid.*|www\.myspace\.com/index\.cfm\?fuseaction=.*&videoid.*|www\.metacafe\.com/watch/.*|www\.metacafe\.com/w/.*|blip\.tv/.*/.*|.*\.blip\.tv/.*/.*|video\.google\.com/videoplay\?.*|.*revver\.com/video/.*|video\.yahoo\.com/watch/.*/.*|video\.yahoo\.com/network/.*|sports\.yahoo\.com/video/.*|.*viddler\.com/explore/.*/videos/.*|liveleak\.com/view\?.*|www\.liveleak\.com/view\?.*|animoto\.com/play/.*|dotsub\.com/view/.*|www\.overstream\.net/view\.php\?oid=.*|www\.livestream\.com/.*|www\.worldstarhiphop\.com/videos/video.*\.php\?v=.*|worldstarhiphop\.com/videos/video.*\.php\?v=.*|teachertube\.com/viewVideo\.php.*|www\.teachertube\.com/viewVideo\.php.*|www1\.teachertube\.com/viewVideo\.php.*|www2\.teachertube\.com/viewVideo\.php.*|bambuser\.com/v/.*|bambuser\.com/channel/.*|bambuser\.com/channel/.*/broadcast/.*|www\.schooltube\.com/video/.*/.*|bigthink\.com/ideas/.*|bigthink\.com/series/.*|sendables\.jibjab\.com/view/.*|sendables\.jibjab\.com/originals/.*|www\.xtranormal\.com/watch/.*|socialcam\.com/v/.*|www\.socialcam\.com/v/.*|dipdive\.com/media/.*|dipdive\.com/member/.*/media/.*|dipdive\.com/v/.*|.*\.dipdive\.com/media/.*|.*\.dipdive\.com/v/.*|v\.youku\.com/v_show/.*\.html|v\.youku\.com/v_playlist/.*\.html|www\.snotr\.com/video/.*|snotr\.com/video/.*|video\.jardenberg\.se/.*|www\.clipfish\.de/.*/.*/video/.*|www\.myvideo\.de/watch/.*|www\.whitehouse\.gov/photos-and-video/video/.*|www\.whitehouse\.gov/video/.*|wh\.gov/photos-and-video/video/.*|wh\.gov/video/.*|www\.hulu\.com/watch.*|www\.hulu\.com/w/.*|www\.hulu\.com/embed/.*|hulu\.com/watch.*|hulu\.com/w/.*|.*crackle\.com/c/.*|www\.fancast\.com/.*/videos|www\.funnyordie\.com/videos/.*|www\.funnyordie\.com/m/.*|funnyordie\.com/videos/.*|funnyordie\.com/m/.*|www\.vimeo\.com/groups/.*/videos/.*|www\.vimeo\.com/.*|vimeo\.com/groups/.*/videos/.*|vimeo\.com/.*|vimeo\.com/m/#/.*|www\.ted\.com/talks/.*\.html.*|www\.ted\.com/talks/lang/.*/.*\.html.*|www\.ted\.com/index\.php/talks/.*\.html.*|www\.ted\.com/index\.php/talks/lang/.*/.*\.html.*|.*nfb\.ca/film/.*|www\.thedailyshow\.com/watch/.*|www\.thedailyshow\.com/full-episodes/.*|www\.thedailyshow\.com/collection/.*/.*/.*|movies\.yahoo\.com/movie/.*/video/.*|movies\.yahoo\.com/movie/.*/trailer|movies\.yahoo\.com/movie/.*/video|www\.colbertnation\.com/the-colbert-report-collections/.*|www\.colbertnation\.com/full-episodes/.*|www\.colbertnation\.com/the-colbert-report-videos/.*|www\.comedycentral\.com/videos/index\.jhtml\?.*|www\.theonion\.com/video/.*|theonion\.com/video/.*|wordpress\.tv/.*/.*/.*/.*/|www\.traileraddict\.com/trailer/.*|www\.traileraddict\.com/clip/.*|www\.traileraddict\.com/poster/.*|www\.escapistmagazine\.com/videos/.*|www\.trailerspy\.com/trailer/.*/.*|www\.trailerspy\.com/trailer/.*|www\.trailerspy\.com/view_video\.php.*|www\.atom\.com/.*/.*/|fora\.tv/.*/.*/.*/.*|www\.spike\.com/video/.*|www\.gametrailers\.com/video/.*|gametrailers\.com/video/.*|www\.koldcast\.tv/video/.*|www\.koldcast\.tv/#video:.*|techcrunch\.tv/watch.*|techcrunch\.tv/.*/watch.*|techcrunch\.tv/show/.*/.*|mixergy\.com/.*|video\.pbs\.org/video/.*|www\.zapiks\.com/.*|tv\.digg\.com/diggnation/.*|tv\.digg\.com/diggreel/.*|tv\.digg\.com/diggdialogg/.*|www\.trutv\.com/video/.*|www\.nzonscreen\.com/title/.*|nzonscreen\.com/title/.*|app\.wistia\.com/embed/medias/.*|hungrynation\.tv/.*/episode/.*|www\.hungrynation\.tv/.*/episode/.*|hungrynation\.tv/episode/.*|www\.hungrynation\.tv/episode/.*|indymogul\.com/.*/episode/.*|www\.indymogul\.com/.*/episode/.*|indymogul\.com/episode/.*|www\.indymogul\.com/episode/.*|channelfrederator\.com/.*/episode/.*|www\.channelfrederator\.com/.*/episode/.*|channelfrederator\.com/episode/.*|www\.channelfrederator\.com/episode/.*|tmiweekly\.com/.*/episode/.*|www\.tmiweekly\.com/.*/episode/.*|tmiweekly\.com/episode/.*|www\.tmiweekly\.com/episode/.*|99dollarmusicvideos\.com/.*/episode/.*|www\.99dollarmusicvideos\.com/.*/episode/.*|99dollarmusicvideos\.com/episode/.*|www\.99dollarmusicvideos\.com/episode/.*|ultrakawaii\.com/.*/episode/.*|www\.ultrakawaii\.com/.*/episode/.*|ultrakawaii\.com/episode/.*|www\.ultrakawaii\.com/episode/.*|barelypolitical\.com/.*/episode/.*|www\.barelypolitical\.com/.*/episode/.*|barelypolitical\.com/episode/.*|www\.barelypolitical\.com/episode/.*|barelydigital\.com/.*/episode/.*|www\.barelydigital\.com/.*/episode/.*|barelydigital\.com/episode/.*|www\.barelydigital\.com/episode/.*|threadbanger\.com/.*/episode/.*|www\.threadbanger\.com/.*/episode/.*|threadbanger\.com/episode/.*|www\.threadbanger\.com/episode/.*|vodcars\.com/.*/episode/.*|www\.vodcars\.com/.*/episode/.*|vodcars\.com/episode/.*|www\.vodcars\.com/episode/.*|confreaks\.net/videos/.*|www\.confreaks\.net/videos/.*|video\.allthingsd\.com/video/.*|videos\.nymag\.com/.*|aniboom\.com/animation-video/.*|www\.aniboom\.com/animation-video/.*|clipshack\.com/Clip\.aspx\?.*|www\.clipshack\.com/Clip\.aspx\?.*|grindtv\.com/.*/video/.*|www\.grindtv\.com/.*/video/.*|ifood\.tv/recipe/.*|ifood\.tv/video/.*|ifood\.tv/channel/user/.*|www\.ifood\.tv/recipe/.*|www\.ifood\.tv/video/.*|www\.ifood\.tv/channel/user/.*|logotv\.com/video/.*|www\.logotv\.com/video/.*|lonelyplanet\.com/Clip\.aspx\?.*|www\.lonelyplanet\.com/Clip\.aspx\?.*|streetfire\.net/video/.*\.htm.*|www\.streetfire\.net/video/.*\.htm.*|trooptube\.tv/videos/.*|www\.trooptube\.tv/videos/.*|sciencestage\.com/v/.*\.html|sciencestage\.com/a/.*\.html|www\.sciencestage\.com/v/.*\.html|www\.sciencestage\.com/a/.*\.html|link\.brightcove\.com/services/player/bcpid.*|wirewax\.com/.*|www\.wirewax\.com/.*|canalplus\.fr/.*|www\.canalplus\.fr/.*|www\.vevo\.com/watch/.*|www\.vevo\.com/video/.*|pixorial\.com/watch/.*|www\.pixorial\.com/watch/.*|www\.godtube\.com/featured/video/.*|godtube\.com/featured/video/.*|www\.godtube\.com/watch/.*|godtube\.com/watch/.*|www\.tangle\.com/view_video.*|mediamatters\.org/mmtv/.*|www\.clikthrough\.com/theater/video/.*|espn\.go\.com/video/clip.*|espn\.go\.com/.*/story.*|abcnews\.com/.*/video/.*|abcnews\.com/video/playerIndex.*|abcnews\.go\.com/.*/video/.*|abcnews\.go\.com/video/playerIndex.*|washingtonpost\.com/wp-dyn/.*/video/.*/.*/.*/.*|www\.washingtonpost\.com/wp-dyn/.*/video/.*/.*/.*/.*|www\.boston\.com/video.*|boston\.com/video.*|www\.boston\.com/.*video.*|boston\.com/.*video.*|www\.facebook\.com/photo\.php.*|www\.facebook\.com/video/video\.php.*|www\.facebook\.com/v/.*|cnbc\.com/id/.*\?.*video.*|www\.cnbc\.com/id/.*\?.*video.*|cnbc\.com/id/.*/play/1/video/.*|www\.cnbc\.com/id/.*/play/1/video/.*|cbsnews\.com/video/watch/.*|www\.google\.com/buzz/.*/.*/.*|www\.google\.com/buzz/.*|www\.google\.com/profiles/.*|google\.com/buzz/.*/.*/.*|google\.com/buzz/.*|google\.com/profiles/.*|www\.cnn\.com/video/.*|edition\.cnn\.com/video/.*|money\.cnn\.com/video/.*|today\.msnbc\.msn\.com/id/.*/vp/.*|www\.msnbc\.msn\.com/id/.*/vp/.*|www\.msnbc\.msn\.com/id/.*/ns/.*|today\.msnbc\.msn\.com/id/.*/ns/.*|www\.globalpost\.com/video/.*|www\.globalpost\.com/dispatch/.*|guardian\.co\.uk/.*/video/.*/.*/.*/.*|www\.guardian\.co\.uk/.*/video/.*/.*/.*/.*|bravotv\.com/.*/.*/videos/.*|www\.bravotv\.com/.*/.*/videos/.*|video\.nationalgeographic\.com/.*/.*/.*\.html|dsc\.discovery\.com/videos/.*|animal\.discovery\.com/videos/.*|health\.discovery\.com/videos/.*|investigation\.discovery\.com/videos/.*|military\.discovery\.com/videos/.*|planetgreen\.discovery\.com/videos/.*|science\.discovery\.com/videos/.*|tlc\.discovery\.com/videos/.*|video\.forbes\.com/fvn/.*))|(https://(twitter\.com/.*/status/.*/photo/.*|twitter\.com/.*/statuses/.*/photo/.*|www\.twitter\.com/.*/status/.*/photo/.*|www\.twitter\.com/.*/statuses/.*/photo/.*|mobile\.twitter\.com/.*/status/.*/photo/.*|mobile\.twitter\.com/.*/statuses/.*/photo/.*|skitch\.com/.*/.*/.*|img\.skitch\.com/.*|itunes\.apple\.com/.*|twitter\.com/.*/status/.*|twitter\.com/.*/statuses/.*|www\.twitter\.com/.*/status/.*|www\.twitter\.com/.*/statuses/.*|mobile\.twitter\.com/.*/status/.*|mobile\.twitter\.com/.*/statuses/.*|foursquare\.com/.*|www\.foursquare\.com/.*|crocodoc\.com/.*|.*\.crocodoc\.com/.*|urtak\.com/u/.*|urtak\.com/clr/.*|ganxy\.com/.*|www\.ganxy\.com/.*|.*youtube\.com/watch.*|.*\.youtube\.com/v/.*|app\.wistia\.com/embed/medias/.*|www\.facebook\.com/photo\.php.*|www\.facebook\.com/video/video\.php.*|www\.facebook\.com/v/.*)))'
        urlSchemes = [embedly_re]
        super(EmbedlyEndPoint, self).__init__(url, urlSchemes=urlSchemes)
        self.apikey = apikey

    def request(self, url, **opt):
        query = opt
        query['key'] = self.apikey
        return super(EmbedlyEndPoint, self).request(url, **query)

class WordpressEndPoint(oembed.OEmbedEndpoint):
    """Wordpress wait a for in his query params"""
    
    def __init__(self):
        url = 'http://public-api.wordpress.com/oembed/1.0/'
        urlSchemes = ['regex:.*.wordpress\.com/.*',]
        super(WordpressEndPoint, self).__init__(url, urlSchemes=urlSchemes)

    def request(self, url, **opt):
        query = opt
        query['for'] = 'plone'
        return super(WordpressEndPoint, self).request(url, **query)

def load_all_endpoints(embedly_apikey=None):
    endpoints = []
    if embedly_apikey is not None:
        endpoint = EmbedlyEndPoint(embedly_apikey)
        endpoints.append(endpoint)

    endpoint = WordpressEndPoint()
    endpoints.append(endpoint)

    providers = REGEX_PROVIDERS

    for provider in providers:
        endpoint = oembed.OEmbedEndpoint(provider[u'endpoint'],
                                         provider[u'regex'])
        endpoints.append(endpoint)
    
    return endpoints



import json
from zope import interface
from zope import schema

from collective.oembed.i18n import messageFactory as _
from collective.oembed import vocabulary

class OEmbedLayer(interface.Interface):
    """browser layer for this addon"""


class IConsumer(interface.Interface):
    """consumer utility"""
    
    def get_data(url, maxwidth=None, maxheight=None, format='json'):
        """Return the data provided by the endpoint"""
    
    def embed(url, maxwidth=None, maxheight=None, format='json'):
        """Return the html code to display the content provided by url."""

class IOEmbedSettings(interface.Interface):
    """Client server side is named consumer"""
    
    embedly_apikey  = schema.ASCIILine(title=_(u'embedlykey'),
                                  required=False)
    
    activate_jqueryoembed_integration = schema.Bool(title=_(u"Activate jquery.oembed integration"),
                                                    description=_(u"If you have installed a jquery.oembed plugin, you can activate integration"),
                                                    default=False)

    #configuration for jquery.oembed javascript
    embedMethod = schema.Choice(title=_(u'embedMethod'),
                                description=_(u'embedMethod_description'),
                                vocabulary=vocabulary.embedMethods,
                                default=u'auto')

    defaultOEmbedProvider = schema.ASCIILine(title=_(u'defaultOEmbedProvider'),
                                             default="embed.ly")

    allowedProviders = schema.List(title=_(u'allowedProviders'),
                                   value_type=schema.ASCIILine(title=_(u'provider')),
                                   default=[],
                                   required=False)

    disallowedProviders = schema.List(title=_(u'disallowedProviders'),
                                   value_type=schema.ASCIILine(title=_(u'provider')),
                                   default=[],
                                   required=False)

    customProviders = schema.List(title=_(u'customProviders'),
                                  value_type=schema.ASCIILine(title=_(u'provider')),
                                  default=[],
                                  required=False)



import json
import StringIO
import urllib
from zope import component
from zope import schema
from plone.app.layout.viewlets import common

from plone.memoize.instance import memoize
from collective.oembed import interfaces
from plone.registry.interfaces import IRegistry
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

class JQueryOEmbedViewlet(common.ViewletBase):
    """This viewlet configure and activate jquery.oembed script"""
    
    index = ViewPageTemplateFile('viewlet-jquery-oembed.pt')
    jsvarname = u'jqueryOmebedSettings'

    def __init__(self, context, request, view, manager=None):
        super(JQueryOEmbedViewlet, self).__init__(context, request, view, manager=None)
        self._settings = None
        self._fields = None

    def get_fields(self):
        if self._fields is None:
            proxy = self.settings()
            self._fields = schema.getFields(proxy.__schema__)
        return self._fields

    def settings(self):
        """Return settings"""

        if self._settings is None:
            registry = component.queryUtility(IRegistry)
            if registry is None:
                return
            try:
                self._settings = registry.forInterface(interfaces.IOEmbedSettings)
            except KeyError, e:
                pass

        return self._settings

    def settings_javascript(self):
        #this is not json, we need to serialize results in unicode manually
        proxy = self.settings()
        encoder = json.JSONEncoder()
        fields = self.get_fields()
        sio = StringIO.StringIO()
        sio.write(u"var %s = {"%self.jsvarname)

        for field in fields:
            value = getattr(proxy, field)
            if value is not None and value != []:
                sio.write(u'%s: %s,'%(field,encoder.encode(value)))
        value = sio.getvalue()

        return u'%s};'%(value[0:-1])

    def check_display_condition(self):
        settings = self.settings()
        if settings is None:
            return False
        try:
            return bool(settings.activate_jqueryoembed_integration)
        except AttributeError,e:
            return False

class Discovery(common.ViewletBase):
    """Add oembed discovery service"""

    index = ViewPageTemplateFile('viewlet-discovery.pt')
    
    def __init__(self, context, request, view, manager=None):
        super(Discovery, self).__init__(context, request, view, manager=None)
        self._query = None
        self._title = None

    def query(self):
        if self._query is None:
            self._query = {'url':self.context.absolute_url()}
        return self._query

    def oembed_url_json(self):
        query = self.query()
        query['format'] = 'json'
        return u'%s/@@oembed?%s'%(self.site_url, urllib.urlencode(query))
    
    def oembed_url_xml(self):
        query = self.query()
        query['format'] = 'xml'
        return u'%s/@@oembed?%s'%(self.site_url, urllib.urlencode(query))
    
    def title(self):
        if self._title is None:
            self._title = u'%s oEmbed Profile'%self.context.Title().decode('utf-8')
        return self._title



from setuptools import setup, find_packages
import os

version = '1.0a'

setup(name='collective.oembed',
      version=version,
      description="embed content from oEmbed-providers as well as make your plonesite being oembed provider",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from
      # http://pypi.python.org/pypi?:action=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.1",
        "Programming Language :: Python",
        ],
      keywords='',
      author='JeanMichel FRANCOIS aka toutpt',
      author_email='toutpt@gmail.com',
      url='https://github.com/collective/collective.oembed',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'python-oembed',
          'plone.app.registry',
          # -*- Extra requirements: -*-
      ],
      extras_require = dict(
          tests=['plone.app.testing'],
      ),
      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )



from collective.oembed.tests import base
from collective.oembed.tests import utils

class Test(base.UnitTestCase):
    
    def setUp(self):
        super(Test, self).setUp()
        from collective.oembed import viewlet
        self.viewlet = viewlet.JQueryOEmbedViewlet(self.context, 
                                                   self.request, None)
        self.viewlet.site_url = 'http://nohost' #no call to update()

    def test_display_condition(self):
        self.failUnless(self.viewlet.check_display_condition()==False)
        self.viewlet._settings = "aaa" #settings not None but not consistent
        self.failUnless(self.viewlet.check_display_condition()==False)
        self.viewlet._settings = utils.FakeProxy()
        self.viewlet._settings.activate_jqueryoembed_integration = True
        self.failUnless(self.viewlet.check_display_condition())

class TestIntegration(base.TestCase):

    def setUp(self):
        super(TestIntegration, self).setUp()
        from collective.oembed import viewlet
        self.viewlet = viewlet.JQueryOEmbedViewlet(self.portal, 
                                                   self.portal.REQUEST, None)
        self.viewlet.site_url = 'http://nohost' #no call to update()    

    def test_display_condition(self):
        self.failUnless(not self.viewlet.check_display_condition())
        self.viewlet.settings().activate_jqueryoembed_integration = True
        self.failUnless(self.viewlet.check_display_condition())

    def test_render(self):
        self.failUnless(not self.viewlet.render()) #should not display
        self.viewlet.settings().activate_jqueryoembed_integration = True
        text = self.viewlet.render()
        call_script = u'$(".oembed").oembed(null,jqueryOmebedSettings);' in text
        self.failUnless(call_script)

def test_suite():
    """This sets up a test suite that actually runs the tests in the class
    above
    """
    return base.build_test_suite((Test, TestIntegration))



class FakeAcquisition(object):
    def __init__(self):
        self.aq_explicit = None

class FakeContext(object):

    def __init__(self):
        self.id = "myid"
        self.title = "a title"
        self.description = "a description"
        self.creators = ["myself"]
        self.date="a date"
        self.aq_inner = FakeAcquisition()
        self.aq_inner.aq_explicit = self
        self._modified = "modified date"
        self.remoteUrl = '' #fake Link
        self.portal_type = 'Document'

    def getId(self):
        return self.id

    def Title(self):
        return self.title

    def Creators(self):
        return self.creators

    def Creator(self):
        return self.creators[0]

    def Description(self):
        return self.description

    def Date(self):
        return self.date

    def modified(self):
        return self._modified

    def getPhysicalPath(self):
        return ('/','a','not','existing','path')

    def getFolderContents(self, filter=None):
        catalog = FakeCatalog()
        return catalog.searchResults()

    def absolute_url(self):
        return "http://nohost.com/"+self.id

    def queryCatalog(self, **kwargs): #fake Topic
        catalog = FakeCatalog()
        return catalog.searchResults()

    def getRemoteUrl(self): #fake Link
        return self.remoteUrl

    def modified(self): #for ram cache key
        return "a modification date"


class FakeBrain(object):
    def __init__(self):
        self.Title = ""
        self.Description = ""
        self.getId = ""
        self.portal_type = ""

    def getURL(self):
        return "http://fakebrain.com"

    def getObject(self):
        ob = FakeContext()
        ob.title = self.Title

        return ob

class FakeCatalog(object):
    def searchResults(self, **kwargs):
        brain1 = FakeBrain()
        brain1.Title = "My first article"
        brain2 = FakeBrain()
        brain2.Title = "A great event"
        brain2.Description = "you will drink lots of beer"
        return [brain1, brain2]

    def modified(self):
        return '654654654654'

class FakeProperty(object):
    def __init__(self):
        self.photo_max_size = 400
        self.thumb_max_size = 80

    def getProperty(self, name, default=None):
        return getattr(self, name, default)

def fake_get_property(self):
    return FakeProperty()

from ZPublisher.tests.testPublish import Request as BaseRequest
def setHeader(header,value):
    pass

class Request(BaseRequest):
    """Request with set item support"""
    
    def __init__(self):
        BaseRequest.__init__(self)
        self.content = {}
        setattr(self.response, 'setHeader', setHeader) #patch for tests

    def __setitem__(self, name, value):
        self.content[name] = value
    
    def get(self, a, b=''):
        return self.content.get(a, b)

class FakeProxy(object):
    def __init__(self):
        self.activate_jqueryoembed_integration = False



from collective.oembed.tests import base

class Test(base.UnitTestCase):
    
    def setUp(self):
        super(Test, self).setUp()
        from collective.oembed import consumer
        self.consumer = consumer.Consumer()

    def test_get_data(self):
        #test noendpoint exception, should return None
        url = 'http://notexisting.com/content'
        data = self.consumer.get_data(url)
        self.assertEqual(data, None)
        
        #test existing content
        url = 'http://www.youtube.com/watch?v=kHikGIWrvCs'
        data = self.consumer.get_data(url, maxwidth=300)
        self.failUnless(data is not None)
        self.failUnless(data[u'type']==u'video')
        self.failUnless(u'collective.oembed' in data[u'title'])
        self.failUnless(data[u'author_url']==u'http://www.youtube.com/user/toutpt')
        self.failUnless(data[u'html'].startswith(u'<iframe' ))
        self.failUnless(data[u'width'] == 300)

    def test_embed(self):
        url = 'http://www.youtube.com/watch?v=kHikGIWrvCs'
        embed = self.consumer.embed(url, maxwidth=310)
        self.failUnless(len(embed)>200) #quite some html code
        self.failUnless(type(embed)==unicode)
        self.failUnless(u"oembed-video" in embed)
        self.failUnless(u"oembed-wrapper" in embed)

    def test_initialize_consumer(self):
        self.failUnless(self.consumer.consumer is None)
        self.consumer.initialize_consumer()
        self.failUnless(self.consumer.consumer is not None)
        #check embedly
        endpoints_count = len(self.consumer.consumer.getEndpoints())
        self.consumer.consumer = None
        self.consumer.embedly_apikey = "123"
        self.consumer.initialize_consumer()
        endpoints_count2 = len(self.consumer.consumer.getEndpoints())
        self.failUnless(endpoints_count + 1 == endpoints_count2)

class TestIntegration(base.TestCase):

    def setUp(self):
        from zope import component
        from collective.oembed import consumer
        from collective.oembed.interfaces import IConsumer
        utility = component.queryUtility(IConsumer)
        self.utility = utility
        self.consumer_class = consumer.Consumer

    def test_get_consumer_utility(self):
        self.failUnless(self.utility is not None)
        self.failUnless(type(self.utility)==self.consumer_class)

    def test_endpoint_youtube(self):
        url = 'http://www.youtube.com/watch?v=kHikGIWrvCs'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

        url = 'http://www.youtube.com/playlist?list=PLF2CEDC7FD9EADDC5'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_flickr(self):
        url = 'http://www.flickr.com/photos/14516334@N00/345009210/'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        url_set = 'http://www.flickr.com/photos/dcplcommons/show'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)

    def test_endpoint_viddler(self):
        url = 'http://www.viddler.com/explore/37signals/videos/40/'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)

    def test_endpoint_qik(self):
        url = 'http://qik.com/video/46087949'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_revision3(self):
        url = 'http://revision3.com/askjay/profitsharing'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_hulu(self):
        url = 'http://www.hulu.com/watch/309602/family-guy-grumpy-old-man'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_slideshare(self):
        url = 'http://www.slideshare.net/irsan.element/merancang-hidup-by-irsan'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"rich")


    def test_endpoint_vimeo(self):
        url = 'http://vimeo.com/20664159'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_collegehumour(self):
        url_video = 'http://www.collegehumor.com/video/6664700/save-greendale-with-the-cast-of-community'
        data = self.utility.get_data(url_video)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]==u"video")

    def test_endpoint_polleverywhere(self):
        url = 'http://www.polleverywhere.com/multiple_choice_polls/LTIwNzM1NTczNTE'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="rich")

    def test_endpoint_ifixit(self):
        url = 'http://www.ifixit.com/Teardown/iPhone-4-Teardown/3130/1'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="rich")

    def test_endpoint_smugmug(self):
        url = 'http://www.smugmug.com/popular/all?125787395_hQSj9#125787395_hQSj9'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="photo")

    def test_endpoint_wordpress(self):
        url = 'http://toutpt.wordpress.com/2011/02/10/collective-portlet-itemview/'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="link",data[u"type"])


    def test_endpoint_23hq(self):
        url = 'http://www.23hq.com/gergana/photo/1376029?album_id=1376028'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="photo",data[u"type"])
        #album doesn't work atm: http://www.23hq.com/photogroup/tech/conversation/7548539

    def test_endpoint_5min(self):
        url = 'http://www.5min.com/Video/How-to-Make-a-Chocolate-Cake-6872'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="video",data[u"type"])

    def test_endpoint_twitter(self):
        url = 'https://twitter.com/#!/toutpt/statuses/153185403766185985'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="rich")

        url = 'https://twitter.com/toutpt/status/153185403766185985'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="rich")

    def test_endpoint_photobucket(self):
        url = 'http://img.photobucket.com/albums/v211/JAV123/Michael%20Holland%20Candle%20Burning/_MG_5661.jpg'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="photo")

    def test_endpoint_kinomap(self):
        url = 'http://www.kinomap.com/#!kms-smfb9r'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="video")

    def test_endpoint_yfrog(self):
        url = 'http://yfrog.com/0wgvcpj'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="photo")

    def test_endpoint_dailymotion(self):
        url = 'http://www.dailymotion.com/video/xf02xp_uffie-difficult_music'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="video")

    def test_endpoint_clikthrough(self):
        url = 'http://www.clikthrough.com/theater/video/55'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="video")

    def test_endpoint_dotsub(self):
        url = 'http://dotsub.com/view/15f0467f-d351-4224-acf5-df3f2ba9d5a0'
        data = self.utility.get_data(url)
        self.failUnless(data is not None)
        self.failUnless(data[u"type"]=="video")

def test_suite():
    """This sets up a test suite that actually runs the tests in the class
    above
    """
    return base.build_test_suite((Test, TestIntegration))
